@@ -51,12 +51,13 @@ impl HidApi {
         }
     }
 
-    pub fn open(&self, vendor_id: c_ushort, product_id: c_ushort) -> Option<HidDevice> {
+    pub fn open(&self, vendor_id: c_ushort, product_id: c_ushort)
+            -> Result<HidDevice, &'static str> {
         let device = unsafe {ffi::hid_open(vendor_id, product_id, std::ptr::null())};
         if device.is_null() {
-            None
+            Err("Can not open hid device.")
         }else {
-            Some(HidDevice {_hid_device: device})
+            Ok(HidDevice {_hid_device: device, api: self})
         }
     }
 }
@@ -136,17 +137,19 @@ pub struct HidDeviceInfo {
     interface_number: c_int,
 }
 
-pub struct HidDevice {
+pub struct HidDevice<'a> {
     _hid_device: *mut ffi::HidDevice,
+    #[allow(dead_code)]
+    api: &'a HidApi, // Just to keep everything safe.
 }
 
-impl Drop for HidDevice {
+impl<'a> Drop for HidDevice<'a> {
     fn drop(&mut self) {
         unsafe {ffi::hid_close(self._hid_device)};
     }
 }
 
-impl HidDevice {
+impl <'a> HidDevice<'a> {
     pub fn write(&self, data: &[u8]) -> c_int {
         unsafe {ffi::hid_write(self._hid_device, data.as_ptr(), data.len() as size_t)}
     }
